RootJobs

Trait RootJobs 

pub trait RootJobs {
    // Required methods
    fn root_path(&self) -> impl AsRef<Path>;
    fn generate_seed_folders(
        &self,
    ) -> Result<Vec<impl SeedFolder + Sync>, SeedingErrors>;

    // Provided methods
    fn get_cell_paths(&self) -> Result<Vec<PathBuf>, SeedingErrors> { ... }
    fn get_cell_entries(&self) -> Result<Vec<CellDocument>, SeedingErrors> { ... }
    fn fetch_potential_files<P: AsRef<Path>>(
        &self,
        potentials_loc: P,
    ) -> Result<(), SeedingErrors> { ... }
    fn build_all<L: AsRef<Path> + Sync, C: CellBuilding + Sync, P: ParamBuilding + Sync>(
        &self,
        cell_builder: &C,
        param_builder: &P,
        potentials_loc: L,
    ) -> Result<(), SeedingErrors> { ... }
}
A trait to process a folder of many cell files.

Required Methods

fn root_path(&self) -> impl AsRef<Path>

fn generate_seed_folders( &self, ) -> Result<Vec<impl SeedFolder + Sync>, SeedingErrors>

Implementation of generation of struct that impl SeedFolder

Provided Methods

fn get_cell_paths(&self) -> Result<Vec<PathBuf>, SeedingErrors>

fn get_cell_entries(&self) -> Result<Vec<CellDocument>, SeedingErrors>

fn fetch_potential_files<P: AsRef<Path>>( &self, potentials_loc: P, ) -> Result<(), SeedingErrors>

fn build_all<L: AsRef<Path> + Sync, C: CellBuilding + Sync, P: ParamBuilding + Sync>( &self, cell_builder: &C, param_builder: &P, potentials_loc: L, ) -> Result<(), SeedingErrors>

Execute all actions to build seed files from .cell files under the root path.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors